# BibleMate AI Agentic Skills

Agentic skill files for third-party AI agents.

For example, Antigravity and OpenClaw can use these files to integrate with BibleMate AI.

# Antigravity

To install the skill globally, create a folder in this directory to `~/.gemini/antigravity/skills/`, and copy the file `SKILL.md` to that folder. Then, restart Antigravity, e.g. `~/.gemini/antigravity/skills/biblemate/SKILL.md`

# OpenClaw

To install the skill globally, create a folder in this directory to `~/.openclaw/skills/`, and copy the file `SKILL.md` to that folder. Then, restart OpenClaw, e.g. `~/.openclaw/skills/biblemate/SKILL.md`